#!/bin/bash

	# if user is not running the command as root
	if [ "$UID" -ne 0 ]; then

		# output message
		echo "Please run the installer with SUDO!"

		# stop script
		exit
	fi

	# define flag
	kernelUpdate=0

	# output message
	echo -e "\nCyberGhost Installer ...\n"

	# get glibc version
	glibcVersion=$(ldd --version | grep -i ldd | awk -F' ' {'print $4'})

	# get distribution version
	distroVersion=$(cat /etc/fedora-release | awk -F' ' {'print $3'})

	echo -e "\nChecking if glibc version is compatible\n"

	# check if GLIBC version is compatible
	if [ "$distroVersion" == "29" ]; then

		if [ "$glibcVersion" == "2.28" ]; then

			echo "The glibc version is compatible, continue..."
		else
			echo "The glibc version is incompatible, exiting setup..."
			exit

		fi
	
	elif [ "$distroVersion" == "30" ]; then

		if [ "$glibcVersion" == "2.29" ]; then

			echo "The glibc version is compatible, continue..."

		else
		
			echo "The glibc version is incompatible, exiting setup..."
			exit

		fi

	elif [ "$distroVersion" == "31" ]; then

		if [ "$glibcVersion" == "2.30" ]; then
		
			echo "The glibc version is compatible, continue..."

		else
		
			echo "The glibc version is incompatible, exiting setup..."
			exit

		fi
	
	elif [ "$distroVersion" == "32" ]; then

		if [ "$glibcVersion" == "2.31" ]; then
		
			echo "The glibc version is compatible, continue..."

		else

			echo "The glibc version is incompatible, exiting setup..."
			exit
		
		fi
	
	else

		echo "Couldn't detect a valid version of your distribution. Make sure you are using Fedora 29,30 or 31"
		exit

	fi
	
	# output message
	echo -n -e "Installing dependencies ... "

	# define required packages
    requiredPackages=(openvpn iptables wireguard-dkms wireguard-tools)

	# loop through packages
    for package in "${requiredPackages[@]}"; do

		# if package is wireguard
		if [ "$package" == "wireguard-dkms" ]; then

			# check if wireguard module exist in kernel
			responseCode=$(lsmod | grep -c wireguard)

			# if ppa does not exist
			if [ "$responseCode" == "0" ]; then

				# output message
				echo -n "The kernel module for Wireguard is missing. Do you want to update to the latest kernel? [Y/n]: "
				read option

				if [ "$option" == "N" ] || [ "$option" == "n" ]; then

					# output message
					echo -n "!!! WARNING !!! If you don\'t update your kernel, Wireguard will not work. Are you sure? [Y/n]: "
					read option
				fi

				# if configuration files can be removed
				if [ "$option" == "Y" ] || [ "$option" == "y" ]; then

					# update kernel
					dnf update kernel kernel-headers -y

					# change flag
					kernelUpdate=1
				fi
			fi

			# check if wireguard ppa exist
			responseCode=$(ls -la  /etc/yum.repos.d/* | grep -c jdoss:wireguard.repo)

			# if ppa does not exist
			if [ "$responseCode" == "0" ]; then

				# install wireguard ppa
				dnf copr enable -y jdoss/wireguard > /dev/null 2>&1
			fi
		fi

		# install package
    	dnf -y install "$package" > /dev/null 2>&1
    done

	# output message
	echo "Done."

	# output message
	echo -e "Continue ..."

	# if directory exist
	if [ -d /usr/local/cyberghost ]; then

		# remove directory
		rm -rf /usr/local/cyberghost
	fi

	echo -e "Installing application ..."

	# if logs directory does not exist
	if [ ! -d /usr/local/cyberghost ]; then

		# create logs directory if not exist
		mkdir /usr/local/cyberghost
	fi

	# copy certificates to local directory
	cp -r cyberghost/* /usr/local/cyberghost

	# change directory permissions
	chmod -R 755 /usr/local/cyberghost

	# output message
	echo -e "Create symlinks ..."

	# if symlink exist
	if [ -L /usr/bin/cyberghostvpn ]; then

		# remove old symlink
		rm /usr/bin/cyberghostvpn
	fi

	# create symlink
	ln -sf /usr/local/cyberghost/cyberghostvpn /usr/bin/cyberghostvpn

	# setup application
	cyberghostvpn --setup

	# if kernel was updated
	if [ $kernelUpdate -eq 1 ]; then

		# output message
		echo
		echo '/--------------------------------------------------------------------------------\'
		echo '| Please REBOOT your computer !!! REQUIRED by kernel update !!! |'
		echo '\--------------------------------------------------------------------------------/'
	fi
